pub struct ArchiveStream {
pub id: ArchiveId,
}Expand description
Serialized arguments for the archive_stream server function.
Fields
id: ArchiveIdMethods from Deref<Target = ArchiveId>
pub fn is_simple(&self) -> bool
pub fn is_simple(&self) -> bool
Returns true if this is a top-level id (contains no forward slashes).
Examples
let top = ArchiveId::from_str("math").unwrap();
assert!(top.is_simple());
let nested = ArchiveId::from_str("math/algebra").unwrap();
assert!(!nested.is_simple());pub fn last(&self) -> &str
pub fn last(&self) -> &str
Returns the last segment of the hierarchical [ArchiveId].
Examples
let archive_id = ArchiveId::from_str("org/project/archive").unwrap();
assert_eq!(archive_id.last(), "archive");
let simple = ArchiveId::from_str("simple").unwrap();
assert_eq!(simple.last(), "simple");pub fn first(&self) -> &str
pub fn first(&self) -> &str
Returns the first segment of the hierarchical [ArchiveId].
Examples
let archive_id = ArchiveId::from_str("org/project/archive").unwrap();
assert_eq!(archive_id.first(), "org");
let simple = ArchiveId::from_str("simple").unwrap();
assert_eq!(simple.first(), "simple");pub fn steps(&self) -> impl DoubleEndedIterator
pub fn steps(&self) -> impl DoubleEndedIterator
Returns an iterator over all segments in the hierarchical [ArchiveId].
The iterator supports both forward and backward iteration.
Examples
let archive_id = ArchiveId::from_str("org/project/archive").unwrap();
let segments: Vec<&str> = archive_id.steps().collect();
assert_eq!(segments, vec!["org", "project", "archive"]);
let reversed: Vec<&str> = archive_id.steps().rev().collect();
assert_eq!(reversed, vec!["archive", "project", "org"]);pub fn is_meta(&self) -> bool
pub fn is_meta(&self) -> bool
Returns true if this [ArchiveId] represents a META-INF archive.
META-INF archives are special archives that contain metadata for all archives in the same identifier space.
Examples
assert!(ArchiveId::from_str("some/path/meta-inf").unwrap().is_meta());
assert!(ArchiveId::from_str("some/path/META-INF").unwrap().is_meta());
assert!(ArchiveId::from_str("some/path/Meta-Inf").unwrap().is_meta());
assert!(!ArchiveId::from_str("some/path/metadata").unwrap().is_meta());
assert!(!ArchiveId::from_str("meta-inf/subpath").unwrap().is_meta());Trait Implementations
Sourceimpl Clone for ArchiveStream
impl Clone for ArchiveStream
Sourcefn clone(&self) -> ArchiveStream
fn clone(&self) -> ArchiveStream
Returns a duplicate of the value. Read more
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArchiveStream
impl Debug for ArchiveStream
Sourceimpl Deref for ArchiveStream
impl Deref for ArchiveStream
Sourceimpl<'de> Deserialize<'de> for ArchiveStream
impl<'de> Deserialize<'de> for ArchiveStream
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ArchiveId> for ArchiveStream
impl From<ArchiveId> for ArchiveStream
Sourceimpl From<ArchiveStream> for ArchiveId
impl From<ArchiveStream> for ArchiveId
Sourcefn from(value: ArchiveStream) -> Self
fn from(value: ArchiveStream) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for ArchiveStream
impl Serialize for ArchiveStream
Sourceimpl ServerFn for ArchiveStream
impl ServerFn for ArchiveStream
Sourceconst PATH: &'static str
const PATH: &'static str
A unique path for the server functionโs API endpoint, relative to the host, including its prefix.
Sourcetype Client = BrowserClient
type Client = BrowserClient
The type of the HTTP client that will send the request from the client side. Read more
Sourcetype Server = AxumServerFnBackend
type Server = AxumServerFnBackend
The type of the HTTP server that will send the response from the server side. Read more
Sourcetype Protocol = Http<GetUrl, Streaming>
type Protocol = Http<GetUrl, Streaming>
The protocol the server function uses to communicate with the client.
Sourcetype Output = ByteStream<ServerFnError<String>>
type Output = ByteStream<ServerFnError<String>>
The return type of the server function. Read more
Sourcetype Error = ServerFnError<String>
type Error = ServerFnError<String>
The type of error in the server function return.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcetype InputStreamError = ServerFnError<String>
type InputStreamError = ServerFnError<String>
The type of error in the server function for stream items sent from the client to the server.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcetype OutputStreamError = ServerFnError<String>
type OutputStreamError = ServerFnError<String>
The type of error in the server function for stream items sent from the server to the client.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcefn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
fn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
Middleware that should be applied to this server function.