pub struct GroupEntries {
pub in: Option<ArchiveId>,
}Expand description
Serialized arguments for the group_entries server function.
Fields
in: Option<ArchiveId>Methods from Deref<Target = Option<ArchiveId>>
1.0.0 ยท Sourcepub fn as_ref(&self) -> Option<&T>
pub fn as_ref(&self) -> Option<&T>
Converts from &Option<T> to Option<&T>.
Examples
Calculates the length of an Option<String> as an Option<usize>
without moving the String. The map method takes the self argument by value,
consuming the original, so this technique uses as_ref to first take an Option to a
reference to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");1.75.0 ยท Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice of the contained value, if any. If this is None, an
empty slice is returned. This can be useful to have a single type of
iterator over an Option or slice.
Note: Should you have an Option<&T> and wish to get a slice of T,
you can unpack it via opt.map_or(&[], std::slice::from_ref).
Examples
assert_eq!(
[Some(1234).as_slice(), None.as_slice()],
[&[1234][..], &[][..]],
);The inverse of this function is (discounting
borrowing) [_]::first:
for i in [Some(1234_u16), None] {
assert_eq!(i.as_ref(), i.as_slice().first());
}1.40.0 ยท Sourcepub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
pub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
Converts from Option<T> (or &Option<T>) to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.
Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));
let x: Option<String> = None;
assert_eq!(x.as_deref(), None);Trait Implementations
Sourceimpl Clone for GroupEntries
impl Clone for GroupEntries
Sourcefn clone(&self) -> GroupEntries
fn clone(&self) -> GroupEntries
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GroupEntries
impl Debug for GroupEntries
Sourceimpl Deref for GroupEntries
impl Deref for GroupEntries
Sourceimpl<'de> Deserialize<'de> for GroupEntries
impl<'de> Deserialize<'de> for GroupEntries
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl From<GroupEntries> for Option<ArchiveId>
impl From<GroupEntries> for Option<ArchiveId>
Sourcefn from(value: GroupEntries) -> Self
fn from(value: GroupEntries) -> Self
Sourceimpl From<Option<ArchiveId>> for GroupEntries
impl From<Option<ArchiveId>> for GroupEntries
Sourceimpl Serialize for GroupEntries
impl Serialize for GroupEntries
Sourceimpl ServerFn for GroupEntries
impl ServerFn for GroupEntries
Sourceconst PATH: &'static str
const PATH: &'static str
Sourcetype Client = BrowserClient
type Client = BrowserClient
Sourcetype Server = AxumServerFnBackend
type Server = AxumServerFnBackend
Sourcetype Protocol = Http<PostUrl, Post<JsonEncoding>>
type Protocol = Http<PostUrl, Post<JsonEncoding>>
Sourcetype Output = (Vec<ArchiveGroupData>, Vec<ArchiveData>)
type Output = (Vec<ArchiveGroupData>, Vec<ArchiveData>)
Sourcetype Error = ServerFnError<String>
type Error = ServerFnError<String>
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcetype InputStreamError = ServerFnError<String>
type InputStreamError = ServerFnError<String>
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcetype OutputStreamError = ServerFnError<String>
type OutputStreamError = ServerFnError<String>
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcefn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
fn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>